@@ -30,7 +30,7 @@
 #include "icqcontacts.h"
 #include "impgp.h"
 
-#define getcolor(c)     conf.getcolor(c)
+#define getcolor(c)     conf->getcolor(c)
 
 accountmanager manager;
 
@@ -82,9 +82,9 @@ void accountmanager::exec() {
 
 	for(pname = icq; pname != protocolname_size; pname++) {
 	    if(pname != rss && gethook(pname).enabled()) {
-		a = conf.getourid(pname);
+		a = conf->getourid(pname);
 
-		n = t.addnode(0, 0, 0, " " + conf.getprotocolname(a.pname) + " ");
+		n = t.addnode(0, 0, 0, " " + conf->getprotocolname(a.pname) + " ");
 		citem = ((int) (a.pname)+1) * 100;
 		capab = gethook(a.pname).getCapabs();
 
@@ -136,6 +136,16 @@ void accountmanager::exec() {
 			break;
 		}
 
+		if(!a.empty())
+		    if(capab.count(hookcapab::acknowledgements))
+			t.addleaff(n, 0, citem+17, _(" Request receipts: %s "),
+			    stryesno(a.additional["acknowledgements"] == "1"));
+#ifdef HAVE_UNAME
+		if(!a.empty())
+                    if(pname == jabber)
+			t.addleaff(n, 0, citem+18, _(" Send OS info: %s "),
+			    stryesno(a.additional["osinfo"] == "1"));
+#endif
 		if(a.empty()) {
 		    t.addnode(n, 0, citem+6, _(" Register "));
 
@@ -161,6 +171,13 @@ void accountmanager::exec() {
 		    if(capab.count(hookcapab::setaway))
 			t.addnode(n, 0, citem+10, _(" Set away message "));
 
+		    if(capab.count(hookcapab::setextstatus))
+		    {
+			if( ( conf->getstatus(pname) != offline ) 
+			&& ( conf->getstatus(pname) != invisible ))
+			t.addnode(n, 0, citem+19, _(" Set external status "));
+		    }
+
 		    t.addnode(n, 0, citem+8, _(" Drop "));
 
 		}
@@ -173,9 +190,10 @@ void accountmanager::exec() {
 	    action = citem-(citem/100)*100;
 	    pname = (protocolname) (citem/100-1);
 
-	    a = conf.getourid(pname);
-	    spname = conf.getprotocolname(pname);
+	    a = conf->getourid(pname);
+	    spname = conf->getprotocolname(pname);
 	    abstracthook &hook = gethook(pname);
+		capab = hook.getCapabs();
 
 	    switch(action) {
 		case 1:
@@ -234,8 +252,8 @@ void accountmanager::exec() {
 		    break;
 
 		case 10:
-		    if(face.edit(tmp = conf.getawaymsg(a.pname), spname + ": " + _("away message"))) {
-			conf.setawaymsg(a.pname, tmp);
+		    if(face.edit(tmp = conf->getawaymsg(a.pname), spname + ": " + _("away message"))) {
+			conf->setawaymsg(a.pname, tmp);
 		    }
 		    break;
 
@@ -282,10 +300,27 @@ void accountmanager::exec() {
 		    if(face.getlastinputkey() != KEY_ESC)
 			a.additional["pgppass"] = tmp;
 		    break;
+
+		case 17:
+		    a.additional["acknowledgements"] =
+			(a.additional["acknowledgements"] == "") ? "1" : "";
+		    break;
+		     
+#ifdef HAVE_UNAME
+		case 18:
+		    a.additional["osinfo"] =
+			(a.additional["osinfo"] == "") ? "1" : "";
+		    break;
+#endif
+		case 19:
+		    if(face.edit(tmp = conf->getextstatus(a.pname, conf->getstatus(pname)), spname + (string)": " + imstatus2str(conf->getstatus(pname)) + (string)" external status" )) {
+			conf->setextstatus(a.pname, tmp, conf->getstatus(pname));
+		    }
+		    break;
 	    }
 
 	    if(action != 7) {
-		conf.setourid(a);
+		conf->setourid(a);
 		mod[a.pname] = true;
 	    }
 	}
@@ -296,9 +331,9 @@ void accountmanager::exec() {
 
     for(pname = icq; pname != protocolname_size; pname++)
 	if(mod[pname])
-	    gethook(pname).ouridchanged(conf.getourid(pname));
+	    gethook(pname).ouridchanged(conf->getourid(pname));
 
-    conf.save();
+    conf->save();
     face.relaxedupdate();
     fopen = false;
 }
