@@ -64,50 +64,50 @@ void imeventmanager::store(const imevent &cev) {
 	    c = clist.get(ev.getcontact());
 
 	    if(!c) {
-		proceed = !conf.getantispam() || 
-			((ev.gettype() == imevent::authorization) && !conf.getdropauthreq()) ||
-			conf.getusingcaptcha();
+		proceed = !conf->getantispam() || 
+			((ev.gettype() == imevent::authorization) && !conf->getdropauthreq()) ||
+			conf->getusingcaptcha();
 
 		if(proceed) {
 		    c = clist.addnew(ev.getcontact());
 		    /* turing test */
-		    if (conf.getdebug()) face.log("captcha: enabled = %i", conf.getusingcaptcha());
-		    if (conf.getusingcaptcha()) {
-			if (conf.getdebug()) face.log("captcha: start");
+		    if (conf->getdebug()) face.log("captcha: enabled = %i", conf->getusingcaptcha());
+		    if (conf->getusingcaptcha()) {
+			if (conf->getdebug()) face.log("captcha: start");
 		        /* If the turing test was failed or not completed, remove
 			 * contact (WE DONT WANT YOU!)
 			 * Note tat below, we always remove the contact if it is not verified */
-			if (!conf.thecaptcha.docaptcha(ev.getcontact())) {
-			    if (conf.getdebug()) face.log("captcha: starting a new turing test with: %s", ev.getcontact().totext().c_str());
+			if (!conf->thecaptcha.docaptcha(ev.getcontact())) {
+			    if (conf->getdebug()) face.log("captcha: starting a new turing test with: %s", ev.getcontact().totext().c_str());
 			    /* have not started the turing test, so send our greeter and message */
 			    store(immessage(
 				c->getdesc(), imevent::outgoing, 
-				conf.getcaptchagreet() + "\n" +
-				conf.thecaptcha.getcaptchaquestion(ev.getcontact())));
+				conf->getcaptchagreet() + "\n" +
+				conf->thecaptcha.getcaptchaquestion(ev.getcontact())));
 			    clist.remove(c->getdesc());
 			    c = 0;
 			} else {
-			    if(conf.getdebug()) face.log("captcha: got an answer: %s", ev.gettext().c_str());
+			    if(conf->getdebug()) face.log("captcha: got an answer: %s", ev.gettext().c_str());
 			    /* have started the test, now must verify the answer */
-			    if (conf.thecaptcha.checkcaptcha(ev.getcontact(), ev.gettext())) {
-			        if (conf.getdebug()) face.log("captcha: received correct answer");
+			    if (conf->thecaptcha.checkcaptcha(ev.getcontact(), ev.gettext())) {
+			        if (conf->getdebug()) face.log("captcha: received correct answer");
 			        /* good, a human */
 				store(immessage(
 				    c->getdesc(), imevent::outgoing, 
-				    conf.getcaptchasuccess()));
-				conf.thecaptcha.donecaptcha(ev.getcontact());
+				    conf->getcaptchasuccess()));
+				conf->thecaptcha.donecaptcha(ev.getcontact());
 			    } else {
-			        if (conf.getdebug()) face.log("captcha: received intorrent answer");
+			        if (conf->getdebug()) face.log("captcha: received intorrent answer");
 				/* bad, a computer (or very dumb human :) */
 				store(immessage(
 				    c->getdesc(), imevent::outgoing, 
-				    conf.getcaptchafailure() + "\n" +
-				    conf.thecaptcha.getcaptchaquestion(ev.getcontact())));
+				    conf->getcaptchafailure() + "\n" +
+				    conf->thecaptcha.getcaptchaquestion(ev.getcontact())));
 			        clist.remove(c->getdesc());
 			        c = 0;
 			    }
 			}
-			if (conf.getdebug()) face.log("captcha: end");
+			if (conf->getdebug()) face.log("captcha: end");
 		    }
 		} else {
 		    face.log("Dropped an authorization request from %s", ev.getcontact().totext().c_str());
@@ -115,7 +115,7 @@ void imeventmanager::store(const imevent &cev) {
 	    }
 	    
 	    if (c) {
-	    	face.xtermtitle(_("event from %s (%s)"), cev.getcontact().totext().c_str(), c->getdispnick().c_str());
+	    	face.xtermtitle(_("event from %s (%s)"), ev.getcontact().totext().c_str(), c->getdispnick().c_str());
 	        eventwrite(ev, history);
 		
 	        c->sethasevents(true);
@@ -149,16 +149,16 @@ void imeventmanager::store(const imevent &cev) {
 
 	if(proceed) {
 	    if(hook->send(ev)) {
-		eventwrite(cev, history);
-		logger.putevent(cev);
+		eventwrite(ev, history);
+		logger.putevent(ev);
 		face.xtermtitle();
 		time(&lastevent);
 		recentlysent++;
 	    } else {
-		eventwrite(cev, offline);
+		eventwrite(ev, offline);
 	    }
 	} else {
-	    eventwrite(cev, offline);
+	    eventwrite(ev, offline);
 	}
     }
 }
@@ -183,6 +183,12 @@ vector<imevent *> imeventmanager::getevents(const imcontact &cont, time_t lastre
 		if(rev) {
 		    if(rev->gettimestamp() > lastread) {
 			rev->setcontact(cont);
+			if(rev->getdirection() == imevent::outgoing && c->receivedAcks.count(rev->gettimestamp()))
+				rev->setack(true);
+			else if(rev->getdirection() == imevent::incoming && c->sentAcks.count(rev->gettimestamp()))
+				rev->setack(true);
+			else
+				rev->setack(false);
 			r.push_back(rev);
 		    } else {
 			delete rev;
