@@ -32,6 +32,7 @@
 #include "imlogger.h"
 #include "icqgroups.h"
 #include "icqcontacts.h"
+#include "impgp.h"
 
 #include "accountmanager.h"
 #include "eventmanager.h"
@@ -75,6 +76,10 @@ icqhook::icqhook(): abstracthook(icq) {
     fcapabs.insert(hookcapab::visibility);
     fcapabs.insert(hookcapab::cltemporary);
     fcapabs.insert(hookcapab::changeabout);
+    
+#ifdef HAVE_GPGME
+    fcapabs.insert(hookcapab::pgp);
+#endif
 
     cli.connected.connect(this, &icqhook::connected_cb);
     cli.disconnected.connect(this, &icqhook::disconnected_cb);
@@ -114,29 +119,29 @@ icqhook::~icqhook() {
 }
 
 void icqhook::init() {
-    manualstatus = conf.getstatus(proto);
+    manualstatus = conf->getstatus(proto);
 
-    if(conf.getdebug())
+    if(conf->getdebug())
 	cli.logger.connect(this, &icqhook::logger_cb);
 }
 
 void icqhook::connect() {
-    icqconf::imaccount acc = conf.getourid(proto);
+    icqconf::imaccount acc = conf->getourid(proto);
     int i, ptpmin, ptpmax;
     icqcontact *c;
 
     if(acc.additional["webaware"].empty()) acc.additional["webaware"] = "1";
-    conf.setourid(acc);
+    conf->setourid(acc);
 
     if(!acc.server.empty()) cli.setLoginServerHost(acc.server);
     if(acc.port) cli.setLoginServerPort(acc.port);
 
-    if(!conf.getsmtphost().empty()) cli.setSMTPServerHost(conf.getsmtphost());
-    if(conf.getsmtpport()) cli.setSMTPServerPort(conf.getsmtpport());
+    if(!conf->getsmtphost().empty()) cli.setSMTPServerHost(conf->getsmtphost());
+    if(conf->getsmtpport()) cli.setSMTPServerPort(conf->getsmtpport());
 
-    if(!conf.getbindhost().empty()) cli.setClientBindHost(conf.getbindhost());
+    if(!conf->getbindhost().empty()) cli.setClientBindHost(conf->getbindhost());
     
-    conf.getpeertopeer(ptpmin, ptpmax);
+    conf->getpeertopeer(ptpmin, ptpmax);
     if(ptpmax) {
 	cli.setAcceptInDC(true);
 	cli.setPortRangeLowerBound(ptpmin);
@@ -381,7 +386,7 @@ bool icqhook::send(const imevent &ev) {
     ContactRef ic = cli.getContact(uin);
     MessageEvent *sev = 0;
     ICQMessageEvent *iev;
-    icqcontact *c;
+    icqcontact *c=clist.get(ev.getcontact());
 
     if(ev.getcontact().pname != proto)
 	uin = 0;
@@ -396,6 +401,13 @@ bool icqhook::send(const imevent &ev) {
 	const immessage *m = static_cast<const immessage *> (&ev);
 	string text = m->gettext(), sub;
 
+#ifdef HAVE_GPGME
+    if ( (c!=NULL) && (pgp.enabled(ev.getcontact())) ) {
+        text = pgp.encrypt(text, c->getpgpkey(), proto);
+        text = "-----BEGIN PGP MESSAGE-----\n\n" + text + "\n-----END PGP MESSAGE-----\n"; 
+    }
+#endif
+
 	if(ic->getStatus() == STATUS_OFFLINE)
 	if(text.size() > 450) {
 	    while(!text.empty()) {
@@ -459,7 +471,7 @@ bool icqhook::send(const imevent &ev) {
 
 	    case imauthorization::Request:
 		sev = new AuthReqEvent(ic, ruscrlfconv("kw", m->getmessage()));
-		if(c = clist.get(ev.getcontact())) {
+		if(c != NULL) {
 		    icqcontact::basicinfo bi = c->getbasicinfo();
 		    bi.authawait = true;
 		    c->setbasicinfo(bi);
@@ -638,7 +650,7 @@ imstatus icqhook::icq2imstatus(const Status st) const {
 
 void icqhook::requestinfo(const imcontact &c) {
     if(logged() && c.uin) {
-	if(c == imcontact(conf.getourid(icq).uin, icq)) {
+	if(c == imcontact(conf->getourid(icq).uin, icq)) {
 	    // Our info is requested
 	    cli.fetchSelfDetailContactInfo();
 	} else {
@@ -768,10 +780,10 @@ void icqhook::sendupdateuserinfo(const icqcontact &c) {
     ic->setWorkInfo(work);
     ic->setAuthReq(cbinfo.requiresauth);
 
-    icqconf::imaccount acc = conf.getourid(icq);
+    icqconf::imaccount acc = conf->getourid(icq);
     acc.additional["webaware"] = cbinfo.webaware ? "1" : "0";
     acc.additional["randomgroup"] = i2str(cbinfo.randomgroup);
-    conf.setourid(acc);
+    conf->setourid(acc);
 
     cli.setWebAware(cbinfo.webaware);
     cli.setRandomChatGroup(cbinfo.randomgroup);
@@ -1007,13 +1019,13 @@ void icqhook::connected_cb(ConnectedEvent *ev) {
 
     logger.putourstatus(icq, offline, manualstatus);
 
-    cli.setRandomChatGroup(strtoul(conf.getourid(icq).additional["randomgroup"].c_str(), 0, 0));
+    cli.setRandomChatGroup(strtoul(conf->getourid(icq).additional["randomgroup"].c_str(), 0, 0));
 
     log(logLogged);
     face.update();
 
     string buf;
-    ifstream f(conf.getconfigfname("icq-infoset").c_str());
+    ifstream f(conf->getconfigfname("icq-infoset").c_str());
 
     if(f.is_open()) {
 	getstring(f, buf); cli.getSelfContact()->setAlias(buf);
@@ -1025,7 +1037,7 @@ void icqhook::connected_cb(ConnectedEvent *ev) {
 	cli.getSelfContact()->getMainHomeInfo().timezone = (Timezone) getSystemTimezone();
 	cli.uploadSelfDetails();
 
-	unlink(conf.getconfigfname("icq-infoset").c_str());
+	unlink(conf->getconfigfname("icq-infoset").c_str());
     }
 
     cli.fetchServerBasedContactList();
@@ -1122,9 +1134,74 @@ void icqhook::messaged_cb(MessageEvent *ev) {
 	else
 	    text = r->getMessage();
 	if(text.substr(0, 6) == "{\\rtf1")
-	    text = fixicqrtf(striprtf(text, converted?conf.getconvertto(proto):conf.getconvertfrom(proto)));
+	    text = fixicqrtf(striprtf(text, converted?conf->getconvertto(proto):conf->getconvertfrom(proto)));
+    
+        text = converted ? text : rusconv("wk", text);
 
-	em.store(immessage(ic, imevent::incoming, converted?text:rusconv("wk", text), r->getTime()));
+#ifdef HAVE_GPGME
+        const string pgpBlockBegin = "-----BEGIN PGP MESSAGE-----";
+        const string pgpBlockEnd = "-----END PGP MESSAGE-----";
+        string enc;
+        int pgpDataBegin = text.find(pgpBlockBegin);
+        int pgpDataEnd = text.find(pgpBlockEnd);
+
+        // find where actual PGP data starts
+        if (pgpDataBegin != string::npos) {
+            int a = text.find("\n\n", pgpDataBegin+1);
+            int b = text.find("\r\n\r\n", pgpDataBegin+1);
+
+            if(a != string::npos) {
+                if(b != string::npos) {
+                    // if we found both, take the smaller value
+                    if (a<b) {
+                        pgpDataBegin = a;
+                    } else {
+                        pgpDataBegin = b;
+                    }
+                } else {
+                    // we didn't find second match, so just take first
+                    pgpDataBegin = a;
+                }
+            } else {
+                // we didn't find first, so take whatever is in second
+                pgpDataBegin = b;
+            }
+        }
+
+        if((pgpDataBegin != string::npos) && (pgpDataEnd != string::npos)) {
+            pgpDataBegin++;
+            enc=text.substr(pgpDataBegin, pgpDataEnd-pgpDataBegin);
+
+            icqcontact *c = clist.get(ic);
+
+            if(c) {
+                if(!enc.empty()) {
+                    c->setusepgpkey(true);
+                    if(pgp.enabled(proto)) {
+                        string dec = pgp.decrypt(enc, proto);
+                        string logMsg;
+
+                       if(dec.length() != 0) {
+                            logMsg="+ "+ic.totext()+" ("+c->getdispnick()+") PGP message decoded";
+                            text = dec;
+                        } else {
+                            // if we fail to decode message,
+                            // just display it as it is
+                            logMsg="+ "+ic.totext()+" ("+c->getdispnick()+") FAILED to decode PGP message";
+                        }
+                        logger.putmessage(logMsg);
+                        face.log(logMsg);
+                    } else {
+                        c->setusepgpkey(false);
+                    }
+                } else {
+                    c->setusepgpkey(false);
+                }
+            }
+        } 
+#endif
+
+	em.store(immessage(ic, imevent::incoming, text, r->getTime()));
 
     } else if(ev->getType() == MessageEvent::URL) {
 	URLMessageEvent *r = static_cast<URLMessageEvent *>(ev);
@@ -1250,7 +1327,7 @@ void icqhook::messageack_cb(MessageEvent *ev) {
 			    rusconv("wk", r->getAwayMessage())));
 		    }
 		} else {
-		    face.log(_("+ [icq] cannot fetch away msg from %s, %s"),
+		    face.log(_("+ [icq] cannot fetch away msg from %s, %s (maybe no away msg set)"),
 			c->getdispnick().c_str(), ic.totext().c_str());
 		}
 		break;
@@ -1394,7 +1471,7 @@ void icqhook::want_auto_resp_cb(ICQMessageEvent *ev) {
     if(c) ident += " (" + c->getdispnick() + ")";
 
     /* logger.putmessage(buf); */
-    ev->setAwayMessage(rusconv("kw", conf.getawaymsg(icq)));
+    ev->setAwayMessage(rusconv("kw", conf->getawaymsg(icq)));
 }
 
 void icqhook::search_result_cb(SearchResultEvent *ev) {
@@ -1432,7 +1509,7 @@ void icqhook::search_result_cb(SearchResultEvent *ev) {
 	    c->setbasicinfo(binfo);
 
 	    foundguys.push_back(c);
-	    searchdest->additem(conf.getcolor(cp_clist_icq), c, line);
+	    searchdest->additem(conf->getcolor(cp_clist_icq), c, line);
 	    searchdest->redraw();
 	}
 
@@ -1457,7 +1534,7 @@ void icqhook::self_contact_userinfo_change_cb(UserInfoChangeEvent *ev) {
 	*
 	*/
 
-	icqconf::imaccount im = conf.getourid(icq);
+	icqconf::imaccount im = conf->getourid(icq);
 	icqcontact::basicinfo cbinfo = c->getbasicinfo();
 	cbinfo.webaware = im.additional["webaware"] == "1";
 	cbinfo.randomgroup = strtoul(im.additional["randomgroup"].c_str(), 0, 0);
@@ -1473,9 +1550,9 @@ void icqhook::self_contact_status_change_cb(StatusChangeEvent *ev) {
 
 void icqhook::password_changed_cb(PasswordChangeEvent *ev) {
     if(ev->isSuccess()) {
-	icqconf::imaccount acc = conf.getourid(icq);
+	icqconf::imaccount acc = conf->getourid(icq);
 	acc.password = ev->getPassword();
-	conf.setourid(acc);
+	conf->setourid(acc);
 	log(logPasswordChanged);
     }
 }
