@@ -27,7 +27,7 @@
 #include <dirent.h>
 #include <fstream>
 
-#if defined(__sun__) || defined(__NetBSD__)
+#if defined(__sun__) || defined(__NetBSD__) || defined(__sgi__)
 #include <sys/statvfs.h>
 #endif
 
@@ -41,6 +41,17 @@
 #include "imlogger.h"
 #include "connwrap.h"
 
+icqconf* icqconf::self=NULL;
+
+icqconf* icqconf::instance()
+{
+	if(!self){
+		self=new icqconf();
+	}
+
+	return self;
+}
+
 icqconf::icqconf() {
     DEFAULT_TIMESTAMP_FORMAT = "DD.MM.YY hh:mm";
     DEFAULT_LOGTIMESTAMP_FORMAT = "%R ";
@@ -57,7 +68,7 @@ icqconf::icqconf() {
 
     hideoffline = antispam = makelog = askaway = logtimestamps =
 	logonline = emacs = proxyssl = proxyconnect = notitles =
-	debug = timestampstothesecond = false;
+	debug = timestampstothesecond = vi = false;
 
     timestampformat = DEFAULT_TIMESTAMP_FORMAT;
     logtimestampformat = DEFAULT_LOGTIMESTAMP_FORMAT;
@@ -80,9 +91,13 @@ icqconf::icqconf() {
         }
     }
     screensocketpath = "/var/run/screen";
+
+    defaultAuthMessage = "Please accept my authorization to add you to my contact list.";
 }
 
 icqconf::~icqconf() {
+	if(self)
+		delete self;
 }
 
 icqconf::imaccount icqconf::getourid(protocolname pname) const {
@@ -137,6 +152,10 @@ void icqconf::setourid(const imaccount &im) {
 	    case jabber:
 		if(i->additional.find("prio") == i->additional.end())
 		    i->additional["prio"] = "4";
+#ifdef HAVE_UNAME
+		if(i->additional.find("osinfo") == i->additional.end())
+		    i->additional["osinfo"] = "1";
+#endif
 		break;
 
 	    case livejournal:
@@ -159,7 +178,7 @@ string icqconf::getawaymsg(protocolname pname) const {
     if(!gethook(pname).getCapabs().count(hookcapab::setaway))
 	return "";
 
-    fname = conf.getconfigfname("awaymsg-" + getprotocolname(pname));
+    fname = conf->getconfigfname("awaymsg-" + getprotocolname(pname));
     f.open(fname.c_str());
 
     if(f.is_open()) {
@@ -191,7 +210,50 @@ void icqconf::setawaymsg(protocolname pname, const string &amsg) {
     if(!gethook(pname).getCapabs().count(hookcapab::setaway))
 	return;
 
-    fname = conf.getconfigfname("awaymsg-" + getprotocolname(pname));
+    fname = conf->getconfigfname("awaymsg-" + getprotocolname(pname));
+    f.open(fname.c_str());
+
+    if(f.is_open()) {
+	f << amsg;
+	f.close();
+    }
+}
+
+string icqconf::getextstatus(protocolname pname, imstatus status) const {
+    string r, buf, fname;
+    ifstream f;
+
+    if(!gethook(pname).getCapabs().count(hookcapab::setextstatus))
+	return "";
+
+    fname = conf->getconfigfname("extmsg-" + getprotocolname(pname) + "-" + imstatus2char[status]);
+    f.open(fname.c_str());
+
+    if(f.is_open()) {
+	while(!f.eof()) {
+	    getstring(f, buf);
+	    if(!r.empty()) r += "\n";
+	    r += buf;
+	}
+
+	f.close();
+    }
+
+    if(r.empty()) {
+	return "";
+    }
+
+    return r;
+}
+
+void icqconf::setextstatus(protocolname pname, const string &amsg, imstatus status) {
+    string fname;
+    ofstream f;
+
+    if(!gethook(pname).getCapabs().count(hookcapab::setextstatus))
+	return;
+
+    fname = conf->getconfigfname("extmsg-" + getprotocolname(pname) + "-" + imstatus2char[status]);
     f.open(fname.c_str());
 
     if(f.is_open()) {
@@ -480,6 +542,7 @@ void icqconf::loadmainconfig() {
 
 	    if(param == "hideoffline") hideoffline = true; else
 	    if(param == "emacs") emacs = true; else
+	    if(param == "vi") vi = true; else
 	    if(param == "autoaway") autoaway = atol(buf.c_str()); else
 	    if(param == "autona") autona = atol(buf.c_str()); else
 	    if(param == "antispam") antispam = true; else
@@ -522,6 +585,7 @@ void icqconf::loadmainconfig() {
 	    if(param == "log_panel_height") logpanelheight = atol(buf.c_str()); else
 	    if(param == "chat_panel_height") chatpanelheight = atol(buf.c_str()); else
 	    if(param == "timestampstothesecond") settimestampstothesecond(true); else
+	    if(param == "defaultauthmessage") defaultAuthMessage = buf; else
 	    if(param == "ptp") {
 		ptpmin = atoi(getword(buf, "-").c_str());
 		ptpmax = atoi(buf.c_str());
@@ -574,36 +638,37 @@ void icqconf::save() {
 	    if(hideoffline) f << "hideoffline" << endl;
 	    if(emacs) f << "emacs" << endl;
 	    if(getquote()) f << "quotemsgs" << endl;
-        if(getantispam()) f << "antispam" << endl;
-        if(getshowopenedchats()) f << "showopenedchats" << endl;
+	    if(vi) f << "vi" << endl;
+            if(getantispam()) f << "antispam" << endl;
+            if(getshowopenedchats()) f << "showopenedchats" << endl;
 	    if(getdropauthreq()) f << "dropauthreq" << endl;
 	    if(getusingcaptcha()) f << "captcha" << endl;
 	    if(getmailcheck()) f << "mailcheck" << endl;
 	    if(getaskaway()) f << "askaway" << endl;
-			if(getscreenna()) f << "screenna" << endl;
-			if(!screensocketpath.empty()) f << "screensocketpath\t" << screensocketpath << endl;
+            if(getscreenna()) f << "screenna" << endl;
+            if(!screensocketpath.empty()) f << "screensocketpath\t" << screensocketpath << endl;
 
 	    param = "";
 	    for(protocolname pname = icq; pname != protocolname_size; pname++)
-		if(getchatmode(pname)) param += (string) " " + conf.getprotocolname(pname);
+		if(getchatmode(pname)) param += (string) " " + conf->getprotocolname(pname);
 	    if(!param.empty())
 		f << "chatmode" << param << endl;
 
 	    param = "";
 	    for(protocolname pname = icq; pname != protocolname_size; pname++)
-		if(getentersends(pname)) param += (string) " " + conf.getprotocolname(pname);
+		if(getentersends(pname)) param += (string) " " + conf->getprotocolname(pname);
 	    if(!param.empty())
 		f << "entersends" << param << endl;
 
 	    param = "";
 	    for(protocolname pname = icq; pname != protocolname_size; pname++)
-		if(getnonimonline(pname)) param += (string) " " + conf.getprotocolname(pname);
+		if(getnonimonline(pname)) param += (string) " " + conf->getprotocolname(pname);
 	    if(!param.empty())
 		f << "nonimonline" << param << endl;
 
 	    param = "";
 	    for(protocolname pname = icq; pname != protocolname_size; pname++)
-		if(getcpconvert(pname)) param += (string) " " + conf.getprotocolname(pname);
+		if(getcpconvert(pname)) param += (string) " " + conf->getprotocolname(pname);
 	    if(!param.empty())
 		f << "convert" << param << endl;
 
@@ -658,6 +723,8 @@ void icqconf::save() {
 	    if(getlogpanelheight()) f << "log_panel_height\t" << getlogpanelheight() << endl;
 	    if(getchatpanelheight()) f << "chat_panel_height\t" << getchatpanelheight() << endl;
 
+	    f << "defaultauthmessage\t" << getDefaultAuthMessage() << endl;
+
 	    vector<imaccount>::iterator ia;
 	    for(ia = accounts.begin(); ia != accounts.end(); ++ia)
 		ia->write(f);
@@ -670,7 +737,7 @@ void icqconf::save() {
 void icqconf::loadcolors() {
     string tname = getconfigfname("colorscheme");
 
-    switch(conf.getregcolor()) {
+    switch(conf->getregcolor()) {
 	case rcdark:
 	    schemer.push(cp_status, "status black/white");
 	    schemer.push(cp_dialog_text, "dialog_text   black/white");
@@ -1106,6 +1173,10 @@ void icqconf::setemacs(bool fem) {
     emacs = fem;
 }
 
+void icqconf::setvi(bool b) {
+    vi = b;
+}
+
 void icqconf::setantispam(bool fas) {
     antispam = fas;
 }
@@ -1303,6 +1374,12 @@ void icqconf::savestatus(protocolname pname, imstatus st) {
     setourid(im);
 }
 
+void icqconf::setavatar(protocolname pname, const string &ava) {
+    imaccount im = getourid(pname);
+    im.additional["avatar"] = ava;
+    setourid(im);
+}
+
 int icqconf::getprotcolor(protocolname pname) const {
     switch(pname) {
 	case icq : return getcolor(cp_clist_icq);
@@ -1398,7 +1475,7 @@ void icqconf::commandline(int argc, char **argv) {
 		<< "Built-in protocols are:";
 
 	    for(protocolname pname = icq; pname != protocolname_size; pname++)
-		if(gethook(pname).enabled()) cout << " " << conf.getprotocolname(pname);
+		if(gethook(pname).enabled()) cout << " " << conf->getprotocolname(pname);
 
 	    cout << endl << endl
 		<< "This is free software; see the source for copying conditions.  There is NO" << endl
@@ -1516,7 +1593,7 @@ const string &dest, const string &number) const {
 
 void icqconf::selfsignal(int signum) const {
     int rpid;
-    ifstream f(conf.getconfigfname("pid").c_str());
+    ifstream f(conf->getconfigfname("pid").c_str());
 
     if(f.is_open()) {
 	f >> rpid;
@@ -1544,7 +1621,7 @@ void icqconf::externalstatuschange(char st, const string &proto) const {
 	try {
 	    if(pname != protocolname_size) {
 		if(imst != imstatus_size) {
-		    string sfname = conf.getconfigfname((string) "status-" + proto);
+		    string sfname = conf->getconfigfname((string) "status-" + proto);
 		    ofstream sf(sfname.c_str());
 		    if(sf.is_open()) sf << imstatus2char[imst], sf.close();
 
@@ -1735,12 +1812,12 @@ string icqconf::gethttpproxypasswd() const {
 void icqconf::checkdiskspace() {
     fenoughdiskspace = true;
 
-#if !(defined(__sun__) || defined(__NetBSD__))
+#if !(defined(__sun__) || defined(__NetBSD__) || defined(__sgi__))
     struct statfs st;
-    if(!statfs(conf.getdirname().c_str(), &st)) {
+    if(!statfs(conf->getdirname().c_str(), &st)) {
 #else
     struct statvfs st;
-    if(!statvfs(conf.getdirname().c_str(), &st)) {
+    if(!statvfs(conf->getdirname().c_str(), &st)) {
 #endif
 	fenoughdiskspace = ((double) st.f_bavail) * st.f_bsize >= 10240;
     }
@@ -1778,13 +1855,13 @@ bool icqconf::imaccount::empty() const {
 }
 
 void icqconf::imaccount::write(ofstream &f) {
-    string prefix = conf.getprotocolname(pname) + "_";
+    string prefix = conf->getprotocolname(pname) + "_";
     map<string, string>::iterator ia;
 
     f << endl;
     if(!nickname.empty()) f << prefix << "nick\t" << nickname << endl;
     if(uin) f << prefix << "uin\t" << uin << endl;
-    if(conf.getsavepwd()) f << prefix << "pass\t" << password << endl;
+    if(conf->getsavepwd()) f << prefix << "pass\t" << password << endl;
     if(!server.empty()) {
 	f << prefix << "server\t" << server;
 	if(port) f << ":" << port;
