@@ -34,7 +34,10 @@
 #include "impgp.h"
 
 #include <libicq2000/constants.h>
+
+#ifdef HAVE_STDINT_H
 #include <stdint.h> /* for intptr_t */
+#endif
 
 const char *stragerange(ICQ2000::AgeRange r) {
     switch(r) {
@@ -87,7 +90,7 @@ bool icqface::sprofmanager(string &name, string &act) {
     map<string, imsearchparams> profiles;
     map<string, imsearchparams>::iterator ip;
 
-    string pfname = conf.getconfigfname("search-profiles");
+    string pfname = conf->getconfigfname("search-profiles");
 
     ifstream f(pfname.c_str());
 
@@ -107,14 +110,14 @@ bool icqface::sprofmanager(string &name, string &act) {
     dy = (LINES-sizeDlg.height)/2+sizeDlg.height;
 
     db.setwindow(new textwindow(dx-(int) (sizeDlg.width*0.6), dy-(int) (sizeDlg.height*0.6),
-	dx, dy, conf.getcolor(cp_dialog_frame), 0, conf.getcolor(cp_dialog_highlight),
+	dx, dy, conf->getcolor(cp_dialog_frame), 0, conf->getcolor(cp_dialog_highlight),
 	_(" Search profiles ")));
 
-    db.setmenu(new verticalmenu(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected)));
+    db.setmenu(new verticalmenu(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected)));
 
-    db.setbar(new horizontalbar(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected), _("Remove"), _("Load"), (char*)0));
+    db.setbar(new horizontalbar(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected), _("Remove"), _("Load"), (char*)0));
 
     db.addkey(KEY_DC, 0);
 
@@ -130,7 +133,7 @@ bool icqface::sprofmanager(string &name, string &act) {
 
 	for(ip = profiles.begin(); ip != profiles.end(); ++ip) {
 	    m.additemf(0, (void *) ip->first.c_str(), " %s: %s",
-		conf.getprotocolname(ip->second.pname).c_str(),
+		conf->getprotocolname(ip->second.pname).c_str(),
 		ip->first.c_str());
 	}
 
@@ -163,7 +166,7 @@ bool icqface::sprofmanager(string &name, string &act) {
 
     db.close();
 
-    unlink(conf.getconfigfname("search-profiles").c_str());
+    unlink(conf->getconfigfname("search-profiles").c_str());
 
     for(ip = profiles.begin(); ip != profiles.end(); ++ip) {
 	ip->second.save(ip->first);
@@ -213,26 +216,26 @@ bool icqface::finddialog(imsearchparams &s, findsubject subj) {
     finished = ret = false;
 
     db.setwindow(new textwindow(0, 0, sizeDlg.width, sizeDlg.height,
-	conf.getcolor(cp_dialog_frame), TW_CENTERED));
+	conf->getcolor(cp_dialog_frame), TW_CENTERED));
 
-    db.settree(new treeview(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected),
-	conf.getcolor(cp_dialog_highlight),
-	conf.getcolor(cp_dialog_text)));
+    db.settree(new treeview(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected),
+	conf->getcolor(cp_dialog_highlight),
+	conf->getcolor(cp_dialog_text)));
 
     switch(subj) {
 	case fsuser:
-	    db.setbar(new horizontalbar(conf.getcolor(cp_dialog_text), conf.getcolor(cp_dialog_selected),
+	    db.setbar(new horizontalbar(conf->getcolor(cp_dialog_text), conf->getcolor(cp_dialog_selected),
 		_("lOad"), _("sAve"), _("cLear"), _("Change"), _("Search/Add"), (char*)0));
 	    break;
 
 	case fschannel:
-	    db.setbar(new horizontalbar(conf.getcolor(cp_dialog_text), conf.getcolor(cp_dialog_selected),
+	    db.setbar(new horizontalbar(conf->getcolor(cp_dialog_text), conf->getcolor(cp_dialog_selected),
 		_("cLear"), _("Change"), _("Join/Create"), (char*)0));
 	    break;
 
 	case fsrss:
-	    db.setbar(new horizontalbar(conf.getcolor(cp_dialog_text), conf.getcolor(cp_dialog_selected),
+	    db.setbar(new horizontalbar(conf->getcolor(cp_dialog_text), conf->getcolor(cp_dialog_selected),
 		_("cLear"), _("Change"), _("lInk"), (char*)0));
 	    break;
     }
@@ -248,7 +251,7 @@ bool icqface::finddialog(imsearchparams &s, findsubject subj) {
 
     };
 
-    db.getwindow()->set_title(conf.getcolor(cp_dialog_highlight), dlgparam[subj].title);
+    db.getwindow()->set_title(conf->getcolor(cp_dialog_highlight), dlgparam[subj].title);
     db.getbar()->item = dlgparam[subj].item;
 
     db.addautokeys();
@@ -294,7 +297,7 @@ bool icqface::finddialog(imsearchparams &s, findsubject subj) {
 
 	if(subj != fsrss) {
 	    i = tree.addnode(_(" Network "));
-	    tree.addleaf(i, 0, 1, " " + conf.getprotocolname(s.pname) + " ");
+	    tree.addleaf(i, 0, 1, " " + conf->getprotocolname(s.pname) + " ");
 	}
 
 	if(subj != fschannel)
@@ -689,6 +692,11 @@ void icqface::gendetails(treeview *tree, icqcontact *c) {
 	tree->addleaff(i, 0, 17, _(" City : %s "), bi.city.c_str());
 	tree->addleaff(i, 0, 14, _(" Gender : %s "), strgender(mi.gender));
     }
+    if(passinfo.pname == jabber)
+    {
+	i = tree->addnode(_(" Miscellaneous "));
+	tree->addleaff(i, 0, 50, _(" Avatar file : %s "), bi.avatar.c_str());
+    }
 
     if(passinfo.pname == rss) {
 	i = tree->addnode(_(" Feed Parameters "));
@@ -727,13 +735,13 @@ bool icqface::updatedetails(icqcontact *c, protocolname upname) {
     passinfo.pname = upname;
 
     textwindow w(0, 0, sizeDlg.width, sizeDlg.height,
-	conf.getcolor(cp_dialog_frame), TW_CENTERED);
+	conf->getcolor(cp_dialog_frame), TW_CENTERED);
 
     if(c->getdesc() == contactroot) {
-	w.set_titlef(conf.getcolor(cp_dialog_highlight), _(" Your %s details "),
-	    conf.getprotocolname(upname).c_str());
+	w.set_titlef(conf->getcolor(cp_dialog_highlight), _(" Your %s details "),
+	    conf->getprotocolname(upname).c_str());
     } else {
-	w.set_titlef(conf.getcolor(cp_dialog_highlight), _(" %s: details "),
+	w.set_titlef(conf->getcolor(cp_dialog_highlight), _(" %s: details "),
 	    c->getdesc().totext().c_str());
     }
 
@@ -741,12 +749,12 @@ bool icqface::updatedetails(icqcontact *c, protocolname upname) {
 
     db.setwindow(&w, false);
 
-    db.settree(new treeview(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected), conf.getcolor(cp_dialog_highlight),
-	conf.getcolor(cp_dialog_text)));
+    db.settree(new treeview(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected), conf->getcolor(cp_dialog_highlight),
+	conf->getcolor(cp_dialog_text)));
 
-    db.setbar(new horizontalbar(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected), _("Change"), _("Done"), (char*)0));
+    db.setbar(new horizontalbar(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected), _("Change"), _("Done"), (char*)0));
 
     db.idle = &detailsidle;
     db.addautokeys();
@@ -866,6 +874,7 @@ bool icqface::updatedetails(icqcontact *c, protocolname upname) {
 		    break;
 		case 48: wi.homepage = inputstr(_("URL: "), wi.homepage); break;
 		case 49: mi.checkfreq = atol(inputstr(_("Check frequency: "), strint(mi.checkfreq)).c_str()); break;
+		case 50: bi.avatar = inputstr(_("Avatar file: "), bi.avatar); break;
 		default:
 		    if(citem >= 100) {
 			vector<pair<string, string> >::iterator ifp = ri.params.begin()+citem-100;
@@ -897,8 +906,8 @@ bool icqface::updatedetails(icqcontact *c, protocolname upname) {
 void icqface::selectcountry(unsigned short &f) {
     int i;
 
-    verticalmenu m(conf.getcolor(cp_dialog_menu), conf.getcolor(cp_dialog_selected));
-    m.setwindow(textwindow(4, LINES-16, 30, LINES-3, conf.getcolor(cp_dialog_menu)));
+    verticalmenu m(conf->getcolor(cp_dialog_menu), conf->getcolor(cp_dialog_selected));
+    m.setwindow(textwindow(4, LINES-16, 30, LINES-3, conf->getcolor(cp_dialog_menu)));
     m.idle = &menuidle;
 
     for(i = 0; i < abstracthook::Country_table_size; i++) {
@@ -918,8 +927,8 @@ void icqface::selectcountry(unsigned short &f) {
 
 void icqface::selectlanguage(unsigned short &f) {
     int i;
-    verticalmenu m(conf.getcolor(cp_dialog_menu), conf.getcolor(cp_dialog_selected));
-    m.setwindow(textwindow(4, LINES-13, 20, LINES-4, conf.getcolor(cp_dialog_menu)));
+    verticalmenu m(conf->getcolor(cp_dialog_menu), conf->getcolor(cp_dialog_selected));
+    m.setwindow(textwindow(4, LINES-13, 20, LINES-4, conf->getcolor(cp_dialog_menu)));
     m.idle = &menuidle;
 
     for(i = 0; i < abstracthook::Language_table_size; i++) {
@@ -935,8 +944,8 @@ void icqface::selectlanguage(unsigned short &f) {
 
 void icqface::selectrandomgroup(unsigned short &f) {
     int i;
-    verticalmenu m(conf.getcolor(cp_dialog_menu), conf.getcolor(cp_dialog_selected));
-    m.setwindow(textwindow(4, LINES-15, 20, LINES-3, conf.getcolor(cp_dialog_menu)));
+    verticalmenu m(conf->getcolor(cp_dialog_menu), conf->getcolor(cp_dialog_selected));
+    m.setwindow(textwindow(4, LINES-15, 20, LINES-3, conf->getcolor(cp_dialog_menu)));
     m.idle = &menuidle;
 
     m.additemf(" %s", _("none"));
@@ -953,8 +962,8 @@ void icqface::selectrandomgroup(unsigned short &f) {
 }
 
 void icqface::selectgender(imgender &f) {
-    verticalmenu m(conf.getcolor(cp_dialog_menu), conf.getcolor(cp_dialog_selected));
-    m.setwindow(textwindow(4, LINES-8, 20, LINES-4, conf.getcolor(cp_dialog_menu)));
+    verticalmenu m(conf->getcolor(cp_dialog_menu), conf->getcolor(cp_dialog_selected));
+    m.setwindow(textwindow(4, LINES-8, 20, LINES-4, conf->getcolor(cp_dialog_menu)));
     m.idle = &menuidle;
 
     for(imgender i = genderUnspec; i != imgender_size; i++) {
@@ -969,8 +978,8 @@ void icqface::selectgender(imgender &f) {
 }
 
 void icqface::selectagerange(ICQ2000::AgeRange &r) {
-    verticalmenu m(conf.getcolor(cp_dialog_menu), conf.getcolor(cp_dialog_selected));
-    m.setwindow(textwindow(4, LINES-8, 18, LINES-3, conf.getcolor(cp_dialog_menu)));
+    verticalmenu m(conf->getcolor(cp_dialog_menu), conf->getcolor(cp_dialog_selected));
+    m.setwindow(textwindow(4, LINES-8, 18, LINES-3, conf->getcolor(cp_dialog_menu)));
     m.idle = &menuidle;
 
     for(ICQ2000::AgeRange i = ICQ2000::RANGE_NORANGE; i <= ICQ2000::RANGE_60_ABOVE; i = ICQ2000::AgeRange(i+1)) {
@@ -994,8 +1003,8 @@ bool icqface::edit(string &txt, const string &header) {
     if(!msb) blockmainscreen();
 
     texteditor se;
-    textwindow w(0, 0, sizeDlg.width, sizeDlg.height, conf.getcolor(cp_dialog_frame), TW_CENTERED);
-    w.set_title(conf.getcolor(cp_dialog_highlight), (string) " " + header + _(" [Ctrl-X save, Esc cancel] "));
+    textwindow w(0, 0, sizeDlg.width, sizeDlg.height, conf->getcolor(cp_dialog_frame), TW_CENTERED);
+    w.set_title(conf->getcolor(cp_dialog_highlight), (string) " " + header + _(" [Ctrl-X save, Esc cancel] "));
     w.open();
 
     editdone = false;
@@ -1032,19 +1041,19 @@ bool icqface::sendfiles(const imcontact &cinfo, string &msg, linkedlist &flist)
 
     blockmainscreen();
 
-    textwindow w(0, 0, sizeDlg.width, sizeDlg.height, conf.getcolor(cp_dialog_frame), TW_CENTERED);
+    textwindow w(0, 0, sizeDlg.width, sizeDlg.height, conf->getcolor(cp_dialog_frame), TW_CENTERED);
 
-    w.set_titlef(conf.getcolor(cp_dialog_highlight),
+    w.set_titlef(conf->getcolor(cp_dialog_highlight),
 	_(" Send file(s) to %s, %lu "),
 	    clist.get(cinfo)->getdispnick().c_str(), cinfo.uin);
 
     db.setwindow(&w, false);
-    db.settree(new treeview(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected), conf.getcolor(cp_dialog_highlight),
-	conf.getcolor(cp_dialog_text)));
+    db.settree(new treeview(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected), conf->getcolor(cp_dialog_highlight),
+	conf->getcolor(cp_dialog_text)));
 
-    db.setbar(new horizontalbar(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected),
+    db.setbar(new horizontalbar(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected),
 	_("Add"), _("Remove"), _("Comment"), _("Send"), (char*)0));
 
     db.addkey(KEY_IC, 0);
@@ -1094,11 +1103,11 @@ void icqface::multichange(bool conv[], bool newstate) {
     protocolname pname;
 
     for(pname = icq; pname != protocolname_size; pname++)
-	if((!conf.getourid(pname).empty() || pname == rss) && conv[pname]) break;
+	if((!conf->getourid(pname).empty() || pname == rss) && conv[pname]) break;
 
     if(pname == protocolname_size || !newstate) {
 	for(pname = icq; pname != protocolname_size; pname++)
-	    if(!conf.getourid(pname).empty() || pname == rss)
+	    if(!conf->getourid(pname).empty() || pname == rss)
 		conv[pname] = newstate;
     }
 }
@@ -1110,42 +1119,43 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
     protocolname pname;
     string tmp, phidden;
 
-    string smtp = conf.getsmtphost() + ":" + i2str(conf.getsmtpport());
-    string browser = conf.getbrowser();
-		string screensocketpath = conf.getscreensocketpath();
+    string smtp = conf->getsmtphost() + ":" + i2str(conf->getsmtpport());
+    string browser = conf->getbrowser();
+		string screensocketpath = conf->getscreensocketpath();
 		
-		bool screenna = conf.getscreenna();
-    bool quote = conf.getquote();
-    bool savepwd = conf.getsavepwd();
-    bool hideoffl = conf.gethideoffline();
-    bool antispam = conf.getantispam();
-    bool showopenedchats = conf.getshowopenedchats();
-    bool dropauthreq = conf.getdropauthreq();
-    bool usingcaptcha = conf.getusingcaptcha();
-    bool mailcheck = conf.getmailcheck();
-    bool makelog = conf.getmakelog();
-    bool askaway = conf.getaskaway();
-    bool bidi = conf.getbidi();
-    bool askquit = conf.getaskquit();
-    bool emacs = conf.getemacs();
-    bool proxyconnect = conf.getproxyconnect();
-    bool timestampstothesecond = conf.gettimestampstothesecond();
+		bool screenna = conf->getscreenna();
+    bool quote = conf->getquote();
+    bool savepwd = conf->getsavepwd();
+    bool hideoffl = conf->gethideoffline();
+    bool antispam = conf->getantispam();
+    bool showopenedchats = conf->getshowopenedchats();
+    bool dropauthreq = conf->getdropauthreq();
+    bool usingcaptcha = conf->getusingcaptcha();
+    bool mailcheck = conf->getmailcheck();
+    bool makelog = conf->getmakelog();
+    bool askaway = conf->getaskaway();
+    bool bidi = conf->getbidi();
+    bool askquit = conf->getaskquit();
+    bool emacs = conf->getemacs();
+	bool vi = conf->getvi();
+    bool proxyconnect = conf->getproxyconnect();
+    bool timestampstothesecond = conf->gettimestampstothesecond();
     bool logtimestamps, logonline;
-    conf.getlogoptions(logtimestamps, logonline);
+    conf->getlogoptions(logtimestamps, logonline);
 
     int ptpmin, ptpmax;
-    conf.getpeertopeer(ptpmin, ptpmax);
+    conf->getpeertopeer(ptpmin, ptpmax);
     bool ptp = ptpmax;
 
     string httpproxy;
-    if (!conf.gethttpproxyuser().empty()) {
-	httpproxy = conf.gethttpproxyuser();
+    if (!conf->gethttpproxyuser().empty()) {
+	httpproxy = conf->gethttpproxyuser();
 	if(!httpproxy.empty())
-	    httpproxy += ":" + conf.gethttpproxypasswd() + "@" + conf.gethttpproxyhost() + ":" + i2str(conf.gethttpproxyport());
+	    httpproxy += ":" + conf->gethttpproxypasswd() + "@" + conf->gethttpproxyhost() + ":" + i2str(conf->gethttpproxyport());
     } else {
-	httpproxy = conf.gethttpproxyhost();
+	httpproxy = conf->gethttpproxyhost();
 	if(!httpproxy.empty())
-	    httpproxy += ":" + i2str(conf.gethttpproxyport());
+	    httpproxy += ":" + i2str(conf->gethttpproxyport());
     }
 
     vector<string> convlanguages;
@@ -1155,45 +1165,45 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
     convlanguages.push_back(_("German UTF-8"));
     vector<string>::const_iterator iconvlang = convlanguages.begin();
 
-    string convertfrom = conf.getconvertfrom();
-    string convertto = conf.getconvertto();
+    string convertfrom = conf->getconvertfrom();
+    string convertto = conf->getconvertto();
 
-    icqconf::groupmode gmode = conf.getgroupmode();
-    icqconf::colormode cm = conf.getcolormode();
-    icqconf::sortmode smode = conf.getsortmode();
+    icqconf::groupmode gmode = conf->getgroupmode();
+    icqconf::colormode cm = conf->getcolormode();
+    icqconf::sortmode smode = conf->getsortmode();
 
     bool chatmode[protocolname_size], conv[protocolname_size],
 	entersends[protocolname_size], nonimonline[protocolname_size];
 
     for(pname = icq; pname != protocolname_size; pname++) {
-	chatmode[pname] = conf.getchatmode(pname);
-	entersends[pname] = conf.getentersends(pname);
-	conv[pname] = conf.getcpconvert(pname);
-	nonimonline[pname] = conf.getnonimonline(pname);
+	chatmode[pname] = conf->getchatmode(pname);
+	entersends[pname] = conf->getentersends(pname);
+	conv[pname] = conf->getcpconvert(pname);
+	nonimonline[pname] = conf->getnonimonline(pname);
     }
 
     for(hasany = false, pname = icq; pname != protocolname_size && !hasany; pname++)
-	hasany = !conf.getourid(pname).empty();
+	hasany = !conf->getourid(pname).empty();
 
     dialogbox db;
 
     finished = success = false;
 
-    conf.getauto(aaway, ana);
+    conf->getauto(aaway, ana);
 
     textwindow w(0, 0, sizeBigDlg.width, sizeBigDlg.height,
-	conf.getcolor(cp_dialog_frame), TW_CENTERED);
+	conf->getcolor(cp_dialog_frame), TW_CENTERED);
 
-    w.set_title(conf.getcolor(cp_dialog_highlight), _(" CenterIM configuration "));
+    w.set_title(conf->getcolor(cp_dialog_highlight), _(" CenterIM configuration "));
 
     db.setwindow(&w, false);
 
-    db.settree(new treeview(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected), conf.getcolor(cp_dialog_highlight),
-	conf.getcolor(cp_dialog_text)));
+    db.settree(new treeview(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected), conf->getcolor(cp_dialog_highlight),
+	conf->getcolor(cp_dialog_text)));
 
-    db.setbar(new horizontalbar(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected), _("Change"), _("Done"), (char*)0));
+    db.setbar(new horizontalbar(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected), _("Change"), _("Done"), (char*)0));
 
     db.idle = &dialogidle;
     db.addautokeys();
@@ -1207,23 +1217,25 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
 	i = t.addnode(_(" User interface "));
 	t.addleaff(i, 0, 1, _(" Change sound device to : %s "), strregsound(s));
 	t.addleaff(i, 0, 2, _(" Change color scheme to : %s "), strregcolor(c));
-	t.addleaff(i, 0, 32, _(" Left panel width :  %d "), conf.getleftpanelwidth());
-	t.addleaff(i, 0, 33, _(" Log panel height :  %d "), conf.getlogpanelheight());
-	t.addleaff(i, 0, 34, _(" Chat panel height : %d "), conf.getchatpanelheight());
+	t.addleaff(i, 0, 35, _(" Change default request authorization message "));
+	t.addleaff(i, 0, 32, _(" Left panel width :  %d "), conf->getleftpanelwidth());
+	t.addleaff(i, 0, 33, _(" Log panel height :  %d "), conf->getlogpanelheight());
+	t.addleaff(i, 0, 34, _(" Chat panel height : %d "), conf->getchatpanelheight());
     t.addleaff(i, 0, 55, _(" Show opened chats : %s "), stryesno(showopenedchats));
 
     #ifdef USE_FRIBIDI
 	t.addleaff(i, 0, 20, _( " Enable bidirectional languages support : %s "), stryesno(bidi));
     #endif
 	t.addleaff(i, 0, 23, _(" Enable emacs bindings in text editor : %s "), stryesno(emacs));
+	t.addleaff(i, 0, 56, _(" Enable vi bindings: %s "), stryesno(vi));
 	t.addleaff(i, 0, 53, _(" Ask before quit : %s "), stryesno(askquit));
 
 	i = t.addnode(_(" Codepages conversion "));
 
 	for(tmp = "", pname = icq; pname != protocolname_size; pname++)
 	if(conv[pname])
-	if(!conf.getourid(pname).empty() || pname == rss)
-	    tmp += conf.getprotocolname(pname) + " ";
+	if(!conf->getourid(pname).empty() || pname == rss)
+	    tmp += conf->getprotocolname(pname) + " ";
 
 	t.addleaff(i, 0, 26, _(" Switch to language preset : %s "), iconvlang->c_str());
 	t.addleaff(i, 0, 27, _(" Remote charset : %s "), convertfrom.c_str());
@@ -1247,14 +1259,14 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
 
 	if(hasany) {
 	    for(tmp = "", pname = icq; pname != protocolname_size; pname++)
-		if(chatmode[pname] && !conf.getourid(pname).empty())
-		    tmp += conf.getprotocolname(pname) + " ";
+		if(chatmode[pname] && !conf->getourid(pname).empty())
+		    tmp += conf->getprotocolname(pname) + " ";
 
 	    t.addleaff(i, 0, 16, _(" Chat messaging mode for : %s"), tmp.c_str());
 
 	    for(tmp = "", pname = icq; pname != protocolname_size; pname++)
-		if(entersends[pname] && !conf.getourid(pname).empty())
-		    tmp += conf.getprotocolname(pname) + " ";
+		if(entersends[pname] && !conf->getourid(pname).empty())
+		    tmp += conf->getprotocolname(pname) + " ";
 
 	    t.addleaff(i, 0, 25, _(" Enter key sends message for : %s"), tmp.c_str());
 
@@ -1265,7 +1277,7 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
 	}
 
 	for(tmp = "", pname = icq; pname != protocolname_size; pname++)
-	    if(nonimonline[pname]) tmp += conf.getprotocolname(pname) + " ";
+	    if(nonimonline[pname]) tmp += conf->getprotocolname(pname) + " ";
 
 	t.addleaff(i, 0, 29, _(" Always online non-IM contacts for : %s"), tmp.c_str());
 	t.addleaff(i, 0, 30, _(" Color contacts according to: %s "), strcolormode(cm));
@@ -1286,7 +1298,7 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
 	i = t.addnode(_(" Logging "));
 	t.addleaff(i, 0, 9, _(" Timestamps in the log window : %s "), stryesno(logtimestamps));
 	t.addleaff(i, 0, 48, _(" Timestamps include seconds : %s "), stryesno(timestampstothesecond));
-	t.addleaff(i, 0, 10, _(" Online/offile events in the log window : %s "), stryesno(logonline));
+	t.addleaff(i, 0, 10, _(" Online/offline events in the log window : %s "), stryesno(logonline));
 	t.addleaff(i, 0, 18, _(" Detailed IM events log in ~/.centerim/log : %s "), stryesno(makelog));
 
 	i = t.addnode(_(" Auto Presence Status "));
@@ -1431,20 +1443,24 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
 			if(!tmp.empty()) browser = tmp;
 		        break;
 		    case 32:    
-		        conf.setleftpanelwidth(atol(inputstr(_("Left panel width: "), 
-		            strint(conf.getleftpanelwidth())).c_str()));
+		        conf->setleftpanelwidth(atol(inputstr(_("Left panel width: "), 
+		            strint(conf->getleftpanelwidth())).c_str()));
 		        needredraw = true;
 		        break;
 		    case 33:
-		        conf.setlogpanelheight(atol(inputstr(_("Log panel height: "), 
-		            strint(conf.getlogpanelheight())).c_str()));
+		        conf->setlogpanelheight(atol(inputstr(_("Log panel height: "), 
+		            strint(conf->getlogpanelheight())).c_str()));
 		        needredraw = true;
 		        break;  
 		    case 34:
-		        conf.setchatpanelheight(atol(inputstr(_("Chat panel height: "), 
-		            strint(conf.getchatpanelheight())).c_str()));
+		        conf->setchatpanelheight(atol(inputstr(_("Chat panel height: "), 
+		            strint(conf->getchatpanelheight())).c_str()));
 		        needredraw = true;
 		        break;
+		    case 35:
+		        conf->setDefaultAuthMessage(inputstr(_("Default authorization request message: "),
+		            conf->getDefaultAuthMessage()));
+		        break;
  
  		    case 48:
 		        timestampstothesecond = !timestampstothesecond; break;
@@ -1478,60 +1494,62 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
 			    smode == icqconf::sort_by_status_and_name ? icqconf::sort_by_activity :
 			    smode == icqconf::sort_by_activity ? icqconf::sort_by_name :
 				icqconf::sort_by_status_and_activity;
-            break;
-            case 55: showopenedchats = !showopenedchats; break;
+			break;
+		    case 55: showopenedchats = !showopenedchats; break;
+		    case 56: vi = !vi; break;
                 
   		}
   		break;
 	    case 1:
 		finished = success = true;
-		conf.setquote(quote);
-		conf.setsavepwd(savepwd);
-		conf.setauto(aaway, ana);
-		conf.setscreenna(screenna);
-		conf.setscreensocketpath(screensocketpath);
-		conf.sethideoffline(hideoffl);
-		conf.setemacs(emacs);
-		conf.setantispam(antispam);
-		conf.setshowopenedchats(showopenedchats);
-		conf.setdropauthreq(dropauthreq);
-		conf.setusingcaptcha(usingcaptcha);
-		conf.setmailcheck(mailcheck);
-		conf.setmakelog(makelog);
-		conf.setaskaway(askaway);
-		conf.setproxyconnect(proxyconnect);
-		conf.settimestampstothesecond(timestampstothesecond);
-		conf.setcharsets(convertfrom, convertto);
+		conf->setquote(quote);
+		conf->setsavepwd(savepwd);
+		conf->setauto(aaway, ana);
+		conf->setscreenna(screenna);
+		conf->setscreensocketpath(screensocketpath);
+		conf->sethideoffline(hideoffl);
+		conf->setemacs(emacs);
+		conf->setvi(vi);
+		conf->setantispam(antispam);
+		conf->setshowopenedchats(showopenedchats);
+		conf->setdropauthreq(dropauthreq);
+		conf->setusingcaptcha(usingcaptcha);
+		conf->setmailcheck(mailcheck);
+		conf->setmakelog(makelog);
+		conf->setaskaway(askaway);
+		conf->setproxyconnect(proxyconnect);
+		conf->settimestampstothesecond(timestampstothesecond);
+		conf->setcharsets(convertfrom, convertto);
 
 		for(pname = icq; pname != protocolname_size; pname++) {
-		    conf.setchatmode(pname, chatmode[pname]);
-		    conf.setentersends(pname, entersends[pname]);
-		    conf.setnonimonline(pname, nonimonline[pname]);
+		    conf->setchatmode(pname, chatmode[pname]);
+		    conf->setentersends(pname, entersends[pname]);
+		    conf->setnonimonline(pname, nonimonline[pname]);
 
 		    bool bconv = conv[pname] && (!convertfrom.empty() || !convertto.empty());
-		    conf.setcpconvert(pname, bconv || !hasany);
+		    conf->setcpconvert(pname, bconv || !hasany);
 		}
 
-		conf.setbidi(bidi);
-		conf.setaskquit(askquit);
-		conf.setlogoptions(logtimestamps, logonline);
+		conf->setbidi(bidi);
+		conf->setaskquit(askquit);
+		conf->setlogoptions(logtimestamps, logonline);
 
-		if(ptp) conf.setpeertopeer(ptpmin, ptpmax);
-		    else conf.setpeertopeer(0, 0);
+		if(ptp) conf->setpeertopeer(ptpmin, ptpmax);
+		    else conf->setpeertopeer(0, 0);
 
-		if(conf.getgroupmode() != gmode) {
-		    conf.setgroupmode(gmode);
+		if(conf->getgroupmode() != gmode) {
+		    conf->setgroupmode(gmode);
 		    clist.rearrange();
 		}
-		conf.setcolormode(cm);
-		if (conf.getsortmode() != smode){
-		    conf.setsortmode(smode);
+		conf->setcolormode(cm);
+		if (conf->getsortmode() != smode){
+		    conf->setsortmode(smode);
 		}
 
-		conf.setsmtphost(smtp);
-		conf.setbrowser(browser);
-		conf.sethttpproxyhost(httpproxy);
-		conf.save();
+		conf->setsmtphost(smtp);
+		conf->setbrowser(browser);
+		conf->sethttpproxyhost(httpproxy);
+		conf->save();
 		break;
 	}
     }
@@ -1574,7 +1592,7 @@ void icqface::selectproto(bool prots[], spmode mode) {
 		if(gethook(pname).getCapabs().count(hookcapab::nochat))
 		    continue;
 
-		if(conf.getourid(pname).empty())
+		if(conf->getourid(pname).empty())
 		    continue;
 
 	    }
@@ -1591,8 +1609,8 @@ void icqface::selectproto(bool prots[], spmode mode) {
     vector<imstatus> mst;
     vector<imstatus>::iterator im;
 
-    verticalmenu m(conf.getcolor(cp_dialog_menu), conf.getcolor(cp_dialog_selected));
-    m.setwindow(textwindow(4, LINES-5-protmax, 18, LINES-4, conf.getcolor(cp_dialog_menu)));
+    verticalmenu m(conf->getcolor(cp_dialog_menu), conf->getcolor(cp_dialog_selected));
+    m.setwindow(textwindow(4, LINES-5-protmax, 18, LINES-4, conf->getcolor(cp_dialog_menu)));
 
     m.idle = &menuidle;
     m.otherkeys = &multiplekeys;
@@ -1604,7 +1622,7 @@ void icqface::selectproto(bool prots[], spmode mode) {
 
 	for(i = 0; i < protmax; i++)
 	    m.additemf(0, i, "[%c] %s", aprots[tempprots[i]] ? 'x' : ' ',
-		conf.getprotocolname(tempprots[i]).c_str());
+		conf->getprotocolname(tempprots[i]).c_str());
 
 	m.setpos(saveelem);
 
@@ -1666,18 +1684,18 @@ int icqface::groupmanager(const string &text, bool sel) {
     bool touched = false;
 
     textwindow w(0, 0, sizeDlg.width, sizeDlg.height,
-	conf.getcolor(cp_dialog_frame), TW_CENTERED);
+	conf->getcolor(cp_dialog_frame), TW_CENTERED);
 
-    w.set_title(conf.getcolor(cp_dialog_highlight), " " + text + " ");
+    w.set_title(conf->getcolor(cp_dialog_highlight), " " + text + " ");
 
     db.setwindow(&w, false);
 
-    db.settree(new treeview(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected), conf.getcolor(cp_dialog_highlight),
-	conf.getcolor(cp_dialog_text)));
+    db.settree(new treeview(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected), conf->getcolor(cp_dialog_highlight),
+	conf->getcolor(cp_dialog_text)));
 
-    db.setbar(new horizontalbar(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected),
+    db.setbar(new horizontalbar(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected),
 	_("Add"), _("Rename"), _("rEmove"), _("move Up"), _("move Down"),
 	sel ? _("Select") : _("Done"), (char*)0));
 
@@ -1789,18 +1807,18 @@ void icqface::transfermonitor() {
     vector< pair< pair<imcontact, imevent::imdirection>, int> >::iterator in;
 
     textwindow w(0, 0, sizeDlg.width, sizeDlg.height,
-	conf.getcolor(cp_dialog_frame), TW_CENTERED);
+	conf->getcolor(cp_dialog_frame), TW_CENTERED);
 
-    w.set_titlef(conf.getcolor(cp_dialog_highlight), " %s ", _("File transfer status"));
+    w.set_titlef(conf->getcolor(cp_dialog_highlight), " %s ", _("File transfer status"));
 
     db.setwindow(&w, false);
 
-    db.settree(new treeview(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected), conf.getcolor(cp_dialog_highlight),
-	conf.getcolor(cp_dialog_text)));
+    db.settree(new treeview(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected), conf->getcolor(cp_dialog_highlight),
+	conf->getcolor(cp_dialog_text)));
 
-    db.setbar(new horizontalbar(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected), _("Cancel"), _("Remove"), (char*)0));
+    db.setbar(new horizontalbar(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected), _("Cancel"), _("Remove"), (char*)0));
 
     db.getbar()->item = 1;
     db.addautokeys();
@@ -1931,8 +1949,8 @@ void icqface::invokelist(string &s, vector<string> &v, const string &def, textwi
     if(vmax < 2) return;
     vmax++;
 
-    verticalmenu m(conf.getcolor(cp_dialog_menu), conf.getcolor(cp_dialog_selected));
-    m.setwindow(textwindow(w->x1, w->y2-vmax, w->x1+30, w->y2, conf.getcolor(cp_dialog_menu)));
+    verticalmenu m(conf->getcolor(cp_dialog_menu), conf->getcolor(cp_dialog_selected));
+    m.setwindow(textwindow(w->x1, w->y2-vmax, w->x1+30, w->y2, conf->getcolor(cp_dialog_menu)));
     m.idle = &menuidle;
 
     vector<string>::const_iterator iv = v.begin();
@@ -2005,15 +2023,15 @@ bool icqface::setljparams(imxmlevent *ev) {
 
     ev->setfield("taglist", "");
 
-    textwindow w(0, 0, sizeDlg.width, sizeDlg.height, conf.getcolor(cp_dialog_frame), TW_CENTERED);
-    w.set_title(conf.getcolor(cp_dialog_highlight), _(" LiveJournal posting: attributes "));
+    textwindow w(0, 0, sizeDlg.width, sizeDlg.height, conf->getcolor(cp_dialog_frame), TW_CENTERED);
+    w.set_title(conf->getcolor(cp_dialog_highlight), _(" LiveJournal posting: attributes "));
     db.setwindow(&w, false);
 
-    db.settree(new treeview(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected), conf.getcolor(cp_dialog_highlight),
-	conf.getcolor(cp_dialog_text)));
+    db.settree(new treeview(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected), conf->getcolor(cp_dialog_highlight),
+	conf->getcolor(cp_dialog_text)));
 
-    db.setbar(new horizontalbar(conf.getcolor(cp_dialog_text), conf.getcolor(cp_dialog_selected),
+    db.setbar(new horizontalbar(conf->getcolor(cp_dialog_text), conf->getcolor(cp_dialog_selected),
 	_("Change"), _("Detect music"), _("Post"), _("cAncel"), (char*)0));
 
     db.addautokeys();
@@ -2076,7 +2094,7 @@ bool icqface::setljparams(imxmlevent *ev) {
 		}
 
 	    } else if(b == 1) {
-		ev->setfield("music", conf.execaction("detectmusic"));
+		ev->setfield("music", conf->execaction("detectmusic"));
 
 	    } else if(b == 2) {
 		r = true;
@@ -2111,9 +2129,9 @@ void icqface::findpgpkey(dialogbox &db, const vector<string> &items) {
     verticalmenu *cm = db.getmenu();
 
     for(fin = false; !fin; ) {
-	attrset(conf.getcolor(cp_dialog_frame));
+	attrset(conf->getcolor(cp_dialog_frame));
 	mvhline(w->y2-2, w->x1+1, HLINE, w->x2-w->x1-2);
-	kwriteatf(w->x1+2, w->y2-2, conf.getcolor(cp_dialog_highlight), "[ %s ]", sub.c_str());
+	kwriteatf(w->x1+2, w->y2-2, conf->getcolor(cp_dialog_highlight), "[ %s ]", sub.c_str());
 	kgotoxy(w->x1+4+sub.size(), w->y2-2);
 	refresh();
 
@@ -2169,7 +2187,7 @@ void icqface::findpgpkey(dialogbox &db, const vector<string> &items) {
 	}
     }
 
-    attrset(conf.getcolor(cp_dialog_frame));
+    attrset(conf->getcolor(cp_dialog_frame));
     mvhline(w->y2-2, w->x1+1, HLINE, w->x2-w->x1-2);
     refresh();
 }
@@ -2184,15 +2202,15 @@ bool icqface::selectpgpkey(string &keyid, bool secretonly) {
     string buf;
     vector<string> items;
 
-    textwindow w(0, 0, sizeDlg.width, sizeDlg.height, conf.getcolor(cp_dialog_frame), TW_CENTERED);
-    w.set_title(conf.getcolor(cp_dialog_highlight), _(" Select PGP key to use "));
+    textwindow w(0, 0, sizeDlg.width, sizeDlg.height, conf->getcolor(cp_dialog_frame), TW_CENTERED);
+    w.set_title(conf->getcolor(cp_dialog_highlight), _(" Select PGP key to use "));
     db.setwindow(&w, false);
 
-    db.setmenu(new verticalmenu(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected)));
+    db.setmenu(new verticalmenu(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected)));
 
-    db.setbar(new horizontalbar(conf.getcolor(cp_dialog_text),
-	conf.getcolor(cp_dialog_selected), _("Select"), 0));
+    db.setbar(new horizontalbar(conf->getcolor(cp_dialog_text),
+	conf->getcolor(cp_dialog_selected), _("Select"), 0));
 
     db.addautokeys();
 
